bayespy.nodes.Mixture
=====================

.. currentmodule:: bayespy.nodes

.. autoclass:: Mixture

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Mixture.__init__
      ~Mixture.add_plate_axis
      ~Mixture.broadcasting_multiplier
      ~Mixture.delete
      ~Mixture.get_gradient
      ~Mixture.get_mask
      ~Mixture.get_moments
      ~Mixture.get_parameters
      ~Mixture.get_riemannian_gradient
      ~Mixture.get_shape
      ~Mixture.has_plotter
      ~Mixture.initialize_from_parameters
      ~Mixture.initialize_from_prior
      ~Mixture.initialize_from_random
      ~Mixture.initialize_from_value
      ~Mixture.integrated_logpdf_from_parents
      ~Mixture.load
      ~Mixture.logpdf
      ~Mixture.lower_bound_contribution
      ~Mixture.lowerbound
      ~Mixture.move_plates
      ~Mixture.observe
      ~Mixture.pdf
      ~Mixture.plot
      ~Mixture.random
      ~Mixture.save
      ~Mixture.set_parameters
      ~Mixture.set_plotter
      ~Mixture.show
      ~Mixture.unobserve
      ~Mixture.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Mixture.dims
      ~Mixture.plates
      ~Mixture.plates_multiplier
   
   